@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,6 +39,9 @@ void ServerSieveSettingsTest::shouldSetValue()
 
 void ServerSieveSettingsTest::shouldEmitEnableOkButtonSignal()
 {
+#if defined(Q_OS_WIN)
+    QSKIP("This test doesn't work on windows");
+#endif
     ServerSieveSettings widget;
     widget.show();
     QVERIFY(QTest::qWaitForWindowExposed(&widget));
@@ -62,6 +65,9 @@ void ServerSieveSettingsTest::shouldEmitEnableOkButtonSignal()
 
 void ServerSieveSettingsTest::shouldEmitSignalWithValueTrue()
 {
+#if defined(Q_OS_WIN)
+    QSKIP("This test doesn't work on windows");
+#endif
     ServerSieveSettings widget;
     widget.show();
     QVERIFY(QTest::qWaitForWindowExposed(&widget));
