@@ -19,7 +19,7 @@
 #include <QJsonObject>
 #include <QWindow>
 #include <kdsingleapplication.h>
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
 #include <private/qtx11extras_p.h>
 #endif
 #endif
@@ -42,6 +42,7 @@ int main(int argc, char **argv)
     KIconTheme::initTheme();
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.sieveeditor"));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral(":/sieveeditor/sieveeditor.svg")));
 #if !WITH_DBUS
     KDSingleApplication sapp;
 #endif
@@ -56,7 +57,7 @@ int main(int argc, char **argv)
                          i18n("Copyright © 2013-%1 sieveeditor authors", QStringLiteral("2025")));
     aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("sieveeditor")));
+    aboutData.setProgramLogo(QIcon::fromTheme(QStringLiteral(":/sieveeditor/sieveeditor.svg")));
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
 
@@ -85,7 +86,7 @@ int main(int argc, char **argv)
         QJsonObject obj;
         obj[QLatin1String("working_dir")] = QDir::currentPath();
         obj[QLatin1String("args")] = QJsonArray::fromStringList(app.arguments());
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
         if (KWindowSystem::isPlatformWayland()) {
             obj[QLatin1String("xdg_activation_token")] = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
         } else if (KWindowSystem::isPlatformX11()) {
@@ -107,7 +108,7 @@ int main(int argc, char **argv)
         QJsonDocument doc = QJsonDocument::fromJson(messageData);
         QJsonObject message = doc.object();
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
         if (KWindowSystem::isPlatformWayland()) {
             qputenv("XDG_ACTIVATION_TOKEN", message[QLatin1String("xdg_activation_token")].toString().toUtf8());
         } else if (KWindowSystem::isPlatformX11()) {
