@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,6 @@
 
 class SieveEditorManageSieveWidget;
 class QTreeWidgetItem;
-namespace KSieveUi
-{
-}
 class SieveEditorScriptManagerWidget : public QWidget
 {
     Q_OBJECT
